@@ -43,7 +43,7 @@
 #include <gtk/gtklabel.h>
 #include <gtk/gtksignal.h>
 #include <gtk/gtkwidget.h>
-#include <libgnome/gnome-i18n.h>
+#include <glib/gi18n.h>
 #include <libgnomevfs/gnome-vfs-types.h>
 #include <libgnomevfs/gnome-vfs-uri.h>
 #include <libnautilus-private/nautilus-file-attributes.h>
@@ -77,6 +77,7 @@ static void		   update_more_info			   (NautilusSidebarTitle      *sidebar_title)
 static void		   update_title_font			   (NautilusSidebarTitle      *sidebar_title);
 static void                style_set                               (GtkWidget                 *widget,
 								    GtkStyle                  *previous_style);
+static guint		   get_best_icon_size 			   (NautilusSidebarTitle      *sidebar_title);
 
 struct NautilusSidebarTitleDetails {
 	NautilusFile		*file;
@@ -172,6 +173,7 @@ nautilus_sidebar_title_init (NautilusSidebarTitle *sidebar_title)
 	gtk_widget_show (sidebar_title->details->notes);
 	gtk_box_pack_start (GTK_BOX (sidebar_title), sidebar_title->details->notes, 0, 0, 0);
 
+	sidebar_title->details->best_icon_size = get_best_icon_size (sidebar_title);
 	/* Keep track of changes in graphics trade offs */
 	update_all (sidebar_title);
 
@@ -320,7 +322,8 @@ update_icon (NautilusSidebarTitle *sidebar_title)
 	} else if (nautilus_icon_factory_is_icon_ready_for_file (sidebar_title->details->file)) {
 		pixbuf = nautilus_icon_factory_get_pixbuf_for_file (sidebar_title->details->file,
 								    "accept",
-								    sidebar_title->details->best_icon_size);
+								    sidebar_title->details->best_icon_size,
+								    FALSE);
 	} else if (sidebar_title->details->determined_icon) {
 		/* We used to know the icon for this file, but now the file says it isn't
 		 * ready. This means that some file info has been invalidated, which
@@ -447,7 +450,12 @@ update_more_info (NautilusSidebarTitle *sidebar_title)
 		g_free (component_info);
 	} else {
 		info_string = g_string_new (NULL);
-		type_string = nautilus_file_get_string_attribute (file, "type");
+
+		type_string = NULL;
+		if (file != NULL && nautilus_file_should_show_type (file)) {
+			type_string = nautilus_file_get_string_attribute (file, "type");
+		}
+
 		if (type_string != NULL) {
 			append_and_eat (info_string, NULL, type_string);
 			append_and_eat (info_string, ", ",
@@ -509,7 +517,7 @@ update_emblems (NautilusSidebarTitle *sidebar_title)
 			(p->data, NULL,
 			 NAUTILUS_ICON_SIZE_STANDARD,
 			 NULL, NULL,
-			 FALSE, NULL);
+			 FALSE, FALSE, NULL);
 		if (pixbuf != NULL) {
 			add_emblem (sidebar_title, pixbuf);
 			g_object_unref (pixbuf);
